class RunnableConfigKeys:
    """The keys for RunnableConfig values."""
    ORIGINAL_USER_PROMPT = 'original_user_prompt'
    ORIGINAL_USER_PROMPT_REWRITE = 'original_user_prompt_rewrite'
    CONVERSATION_ID = 'conversation_id'
    FILE_HISTORY = 'file_history'
